<template lang="pug">
.container
  ModalDialogConfirm(
    cancel-text="Plus tard"
    cancel-role="danger"
    confirm-text="Configurer l'emploi du temps"
    name="skip"
    @confirm="skip()"
  )
    p
      | Si vous passez cette étape, de nombreuses fonctionnalités ne seront pas disponibles:
      ul
        li Temps restant dans le cours actuel
        li Timeline
        li Sélection de date intelligente pour les devoirs
    p Vous pouvez toujours rajouter l'emploi du temps plus tard.
  h1 Votre emploi du temps
  ul.settings
    li(v-for="setting in settings" :key="setting.uuid")
      InputSetting(v-bind="{...setting, _key: setting.key, value: null}")
  TheBottomBar
    ButtonNormal(variant="text-blue" href="/setup/subjects") #[Icon arrow_back] Retour
    ButtonNormal.to-right(variant="outline" @click="$modal.open('confirm-skip')" ) Passer
    ButtonNormal(variant="primary" href="/setup/schedule/events") Continuer
</template>

<script>
import { mapGetters, mapActions } from 'vuex'
import ModalDialogConfirm from '~/components/legacy/ModalDialogConfirm.vue'
import TheBottomBar from '~/components/legacy/TheBottomBar.vue'
import Icon from '~/components/legacy/Icon.vue'
import ButtonNormal from '~/components/legacy/ButtonNormal.vue'
import InputSetting from '~/components/legacy/InputSetting.vue'

export default {
  components: {
    Icon,
    ButtonNormal,
    InputSetting,
    TheBottomBar,
    ModalDialogConfirm,
  },
  layout: 'bare',
  computed: {
    ...mapGetters('settings', ['all']),
    settings() {
      return this.all.filter(
        s => !s.optional && !s.hidden && s.category === 'Emploi du temps'
      )
    },
  },
  mounted() {
    this.$withLoadingScreen(async () => {
      await this.$store.dispatch('settings/load')
    })
  },
  methods: {
    ...mapActions({
      setSetting: 'settings/setValue',
    }),
    async skip() {
      await this.setSetting({
        key: 'use_schedule',
        value: false,
      })
      // setValue is debounced to 500ms
      setTimeout(() => {
        this.$auth.fetchUser()
        this.$router.push('/')
        this.$modal.close('confirm-skip')
      }, 500)
    },
  },
}
</script>

<style lang="stylus" scoped>
.container
  display flex
  flex-direction column
  justify-content center
  align-items center
  margin-bottom 100px //scroll space needed because of <TheBottomBar>

h1
  margin-bottom 1em
  text-align center

ul.settings
  li
    margin-bottom 1em
</style>
